"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SNSHelper = void 0;
const AWS = require("aws-sdk");
const typescript_helper_functions_1 = require("typescript-helper-functions");
/**
 * SNS Helper
 */
class SNSHelper extends typescript_helper_functions_1.BaseClass {
    /**
     * Initializes new instance of SNSHelper
     * @param logger {ILogger} Injected logger
     * @param repository {AWS.SNS} Injected Repository. A new repository will be created if not supplied
     * @param options {AWS.SNS.ClientConfiguration} Injected configuration if a Repository is supplied
     */
    constructor(logger, repository, options) {
        super(logger);
        this.Repository = repository || new AWS.SNS(options);
    }
    /**
     * Publish a message
     * @param topicArn {string} Topic ARN to publish to
     * @param subject {string} Subject of message to send
     * @param message {string} Contents of message to send
     * @param messageAttributes {AWS.SNS.MessageAttributeMap} Attributes to give the message to send
     */
    PublishAsync(topicArn, subject, message, messageAttributes) {
        return __awaiter(this, void 0, void 0, function* () {
            const action = `${SNSHelper.name}.${this.PublishAsync.name}`;
            this.LogHelper.LogInputs(action, { topicArn, subject, message, messageAttributes });
            // guard clauses
            if (this.ObjectOperations.IsNullOrWhitespace(topicArn)) {
                throw new Error(`[${action}]-Must supply topicArn`);
            }
            if (this.ObjectOperations.IsNullOrWhitespace(subject)) {
                throw new Error(`[${action}]-Must supply subject`);
            }
            if (this.ObjectOperations.IsNullOrWhitespace(message)) {
                throw new Error(`[${action}]-Must supply message`);
            }
            // create params object
            const params = {
                Message: message,
                MessageAttributes: messageAttributes,
                Subject: subject,
                TopicArn: topicArn,
            };
            this.LogHelper.LogRequest(action, params);
            // make AWS call
            const response = yield this.Repository.publish(params).promise();
            this.LogHelper.LogResponse(action, response);
            return response;
        });
    }
}
exports.SNSHelper = SNSHelper;
//# sourceMappingURL=helper.js.map