"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const typescript_ilogger_1 = require("typescript-ilogger");
const test_values_1 = require("./test-values");
const helper_1 = require("./helper");
const mock_1 = require("./mock");
const logger = new typescript_ilogger_1.Logger(typescript_ilogger_1.LogLevel.Off);
const mockerResolves = new mock_1.SNSMock(false);
const snsHelperMockResolves = new helper_1.SNSHelper(logger, mockerResolves.Mock);
const mockerRejects = new mock_1.SNSMock(true);
const snsHelperMockRejects = new helper_1.SNSHelper(logger, mockerRejects.Mock);
const TestValues = new test_values_1.TestingValues();
/**
 * Test the PublishAsync method
 */
describe(`${helper_1.SNSHelper.name}.${snsHelperMockResolves.PublishAsync.name}`, () => {
    // set action for this method
    const action = `${helper_1.SNSHelper.name}.${snsHelperMockResolves.PublishAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} topicArn`, () => {
        const actual = snsHelperMockResolves.PublishAsync(TestValues.EmptyString, TestValues.Subject, TestValues.Body);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} topicArn`);
    });
    test(`${TestValues.ThrowsOnEmpty} subject`, () => {
        const actual = snsHelperMockResolves.PublishAsync(TestValues.Arn, TestValues.EmptyString, TestValues.Body);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} subject`);
    });
    test(`${TestValues.ThrowsOnEmpty} message`, () => {
        const actual = snsHelperMockResolves.PublishAsync(TestValues.Arn, TestValues.Subject, TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} message`);
    });
    test(TestValues.InvalidTest, () => {
        const actual = snsHelperMockRejects.PublishAsync(TestValues.Arn, TestValues.Subject, TestValues.Body);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
    test(TestValues.ValidTest, () => {
        const actual = snsHelperMockResolves.PublishAsync(TestValues.Arn, TestValues.Subject, TestValues.Body);
        return expect(actual).resolves.toEqual(mockerResolves.PublishResponse);
    });
});
//# sourceMappingURL=helper.spec.js.map